@@ -1,13 +1,13 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "richtextcomposerwidget.h"
+#include <QHBoxLayout>
 #include <kpimtextedit/richtextcomposer.h>
 #include <kpimtextedit/richtexteditorwidget.h>
-#include <QHBoxLayout>
 
 using namespace KPIMTextEdit;
 
@@ -25,11 +25,11 @@ RichTextComposerWidget::RichTextComposerWidget(QWidget *parent)
     : QWidget(parent)
     , d(new KPIMTextEdit::RichTextComposerWidgetPrivate)
 {
-    auto *layout = new QHBoxLayout(this);
+    auto layout = new QHBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
     d->richTextComposer = new KPIMTextEdit::RichTextComposer(this);
     d->richTextComposer->setObjectName(QStringLiteral("richtextcomposer"));
-    auto *editorWidget = new RichTextEditorWidget(d->richTextComposer, this);
+    auto editorWidget = new RichTextEditorWidget(d->richTextComposer, this);
     layout->addWidget(editorWidget);
 }
 
