@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KPIMTEXTEDITRICHTEXTEXTERNALCOMPOSER_H
@@ -24,14 +11,19 @@
 #include <QObject>
 #include <QProcess>
 
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class RichTextComposer;
+/**
+ * @brief The RichTextExternalComposer class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class KPIMTEXTEDIT_EXPORT RichTextExternalComposer : public QObject
 {
     Q_OBJECT
 public:
     explicit RichTextExternalComposer(RichTextComposer *composer, QObject *parent = nullptr);
-    ~RichTextExternalComposer();
+    ~RichTextExternalComposer() override;
 
     Q_REQUIRED_RESULT bool useExternalEditor() const;
     void setUseExternalEditor(bool value);
