@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
   based on code from kopete
 
   SPDX-License-Identifier: LGPL-2.0-or-later
@@ -8,8 +8,8 @@
 #include "emoticontexteditselector.h"
 
 #include <KLocalizedString>
-#include <QMenu>
 #include <QIcon>
+#include <QMenu>
 
 #include <QWidgetAction>
 
@@ -22,7 +22,7 @@ public:
         : emoticonMenu(new QMenu())
     {
         selector = new EmoticonTextEditSelector(emoticonMenu);
-        auto *action = new QWidgetAction(emoticonMenu);
+        auto action = new QWidgetAction(emoticonMenu);
         action->setDefaultWidget(selector);
         emoticonMenu->addAction(action);
         connect(emoticonMenu, &QMenu::aboutToShow, selector, &EmoticonTextEditSelector::loadEmoticons);
@@ -44,7 +44,7 @@ EmoticonTextEditAction::EmoticonTextEditAction(QObject *parent)
     delete menu();
     setMenu(d->emoticonMenu);
     setIcon(QIcon::fromTheme(QStringLiteral("face-smile")));
-    setDelayed(false);
+    setPopupMode(QToolButton::InstantPopup);
     connect(d->selector, &EmoticonTextEditSelector::itemSelected, this, &EmoticonTextEditAction::emoticonActivated);
 }
 
