@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
   based on code from kopete
 
   SPDX-License-Identifier: LGPL-2.0-or-later
@@ -9,14 +9,15 @@
 #define KPIMTEXTEDIT_EMOTICONTEXTEDITSELECTOR_H
 
 #include <QWidget>
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class EmoticonUnicodeTab;
 class EmoticonTextEditSelector : public QWidget
 {
     Q_OBJECT
 public:
     explicit EmoticonTextEditSelector(QWidget *parent = nullptr);
-    ~EmoticonTextEditSelector();
+    ~EmoticonTextEditSelector() override;
 
 public Q_SLOTS:
     void loadEmoticons();
