@@ -1,29 +1,16 @@
 /*
-  Copyright (c) 2019-2020 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2019-2020 Montel Laurent <montel@kde.org>
   based on grantlee PlainTextMarkupBuilder
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
 #ifndef PLAINTEXTMARKUPBUILDER_H
 #define PLAINTEXTMARKUPBUILDER_H
 
-#include "kpimtextedit_export.h"
 #include "abstractmarkupbuilder.h"
+#include "kpimtextedit_export.h"
 
 #define LETTERSINALPHABET 26
 #define DIGITSOFFSET 10
@@ -31,8 +18,7 @@
 namespace KPIMTextEdit
 {
 class PlainTextMarkupBuilderPrivate;
-class KPIMTEXTEDIT_EXPORT PlainTextMarkupBuilder
-        : virtual public KPIMTextEdit::AbstractMarkupBuilder
+class KPIMTEXTEDIT_EXPORT PlainTextMarkupBuilder : virtual public KPIMTextEdit::AbstractMarkupBuilder
 {
 public:
     /** Construct a new PlainTextHTMLMarkupBuilder. */
@@ -42,7 +28,6 @@ public:
 
     void setQuotePrefix(const QString &prefix);
 
-
     void beginStrong() override;
     void endStrong() override;
     void beginEmph() override;
@@ -52,14 +37,11 @@ public:
     void beginStrikeout() override;
     void endStrikeout() override;
 
-    void beginAnchor(const QString &href = QString(),
-                     const QString &name = QString()) override;
+    void beginAnchor(const QString &href = QString(), const QString &name = QString()) override;
 
     void endAnchor() override;
 
-    void beginParagraph(Qt::Alignment a = Qt::AlignLeft, qreal top = 0.0,
-                        qreal bottom = 0.0, qreal left = 0.0,
-                        qreal right = 0.0) override;
+    void beginParagraph(Qt::Alignment a = Qt::AlignLeft, qreal top = 0.0, qreal bottom = 0.0, qreal left = 0.0, qreal right = 0.0) override;
 
     void endParagraph() override;
     void addNewline() override;
@@ -84,13 +66,11 @@ public:
 
     void endSubscript() override;
 
-    void beginTable(qreal cellpadding, qreal cellspacing,
-                    const QString &width) override;
+    void beginTable(qreal cellpadding, qreal cellspacing, const QString &width) override;
 
     void beginTableRow() override;
 
-    void beginTableHeaderCell(const QString &width, int colSpan,
-                              int rowSpan) override;
+    void beginTableHeaderCell(const QString &width, int colSpan, int rowSpan) override;
 
     void beginTableCell(const QString &width, int colSpan, int rowSpan) override;
 
@@ -102,14 +82,14 @@ public:
     Adds a reference to @p reference to the internal list of references in the
     document.
   */
-    int addReference(const QString &reference);
+    Q_REQUIRED_RESULT int addReference(const QString &reference);
 
     /**
     Returns the finalised plain text markup, including references at the end.
   */
-    QString getResult() override;
+    Q_REQUIRED_RESULT QString getResult() override;
 
-    bool isQuoteBlock(qreal top, qreal bottom, qreal left, qreal right) const;
+    Q_REQUIRED_RESULT bool isQuoteBlock(qreal top, qreal bottom, qreal left, qreal right) const;
 
     void beginForeground(const QBrush &brush) override;
     void endForeground() override;
@@ -126,10 +106,10 @@ public:
     void beginHeader(int level) override;
     void endHeader(int level) override;
     void addSingleBreakLine() override;
+
 private:
     PlainTextMarkupBuilderPrivate *const d_ptr;
     Q_DECLARE_PRIVATE(PlainTextMarkupBuilder)
-
 };
 }
 
