@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,11 +7,12 @@
 #ifndef TEXTTOSPEECHACTIONS_H
 #define TEXTTOSPEECHACTIONS_H
 
-#include <QObject>
 #include "kpimtextedit_export.h"
 #include "texttospeechwidget.h"
+#include <QObject>
 class QAction;
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class TextToSpeechActionsPrivate;
 /**
  * @brief The TextToSpeechActions class
@@ -22,7 +23,7 @@ class KPIMTEXTEDIT_EXPORT TextToSpeechActions : public QObject
     Q_OBJECT
 public:
     explicit TextToSpeechActions(QObject *parent = nullptr);
-    ~TextToSpeechActions();
+    ~TextToSpeechActions() override;
 
     QAction *stopAction() const;
 
