@@ -1,19 +1,19 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "texttospeechwidget.h"
 #include "texttospeechactions.h"
-#include "texttospeechinterface.h"
 #include "texttospeechconfigdialog.h"
+#include "texttospeechinterface.h"
 #include <KLocalizedString>
 #include <QHBoxLayout>
-#include <QToolButton>
 #include <QLabel>
-#include <QSlider>
 #include <QPointer>
+#include <QSlider>
+#include <QToolButton>
 
 using namespace KPIMTextEdit;
 
@@ -38,12 +38,12 @@ TextToSpeechWidget::TextToSpeechWidget(QWidget *parent)
     : QWidget(parent)
     , d(new KPIMTextEdit::TextToSpeechWidgetPrivate)
 {
-    auto *hbox = new QHBoxLayout(this);
+    auto hbox = new QHBoxLayout(this);
 
     d->mTextToSpeechActions = new TextToSpeechActions(this);
     connect(d->mTextToSpeechActions, &TextToSpeechActions::stateChanged, this, &TextToSpeechWidget::stateChanged);
 
-    auto *close = new QToolButton(this);
+    auto close = new QToolButton(this);
     close->setObjectName(QStringLiteral("close-button"));
     close->setIcon(QIcon::fromTheme(QStringLiteral("dialog-close")));
     close->setToolTip(i18n("Close"));
@@ -147,7 +147,7 @@ void TextToSpeechWidget::slotStateChanged(KPIMTextEdit::TextToSpeech::State stat
         }
         break;
     default:
-        //TODO
+        // TODO
         break;
     }
 }
@@ -161,7 +161,7 @@ void TextToSpeechWidget::setTextToSpeechInterface(AbstractTextToSpeechInterface
 {
     delete d->mTextToSpeechInterface;
     d->mTextToSpeechInterface = interface;
-    //Update volume value
+    // Update volume value
     if (d->mTextToSpeechInterface) {
         d->mTextToSpeechInterface->reloadSettings();
         d->mVolume->setValue(interface->volume());
